/*
 * Copyright 2024 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef SENSETIMENLPENGINE_H
#define SENSETIMENLPENGINE_H

#include <kylin-ai/ai-engine/cloudnlpengine.h>

class SensetimeNlpEnginePrivate;

class SensetimeNlpEngine : public ai_engine::nlp::AbstractCloudNlpEngine {
public:
    SensetimeNlpEngine();
    ~SensetimeNlpEngine();
    std::string engineName() const override;
    std::string currentModelName() const override;
    int maxConcurrentChatTasks() const override;

    void setConfig(const std::string &config) override;
    std::string modelInfo() const override;

    void
    setChatResultCallback(ai_engine::nlp::ChatResultCallback callback) override;

    void setContextSize(int size) override;
    void clearContext() override;

    bool chat(const std::string &message,
              ai_engine::EngineError &error) override;
    void stopChat() override;

    bool initChatModule(ai_engine::EngineError &error) override;
    bool destroyChatModule(ai_engine::EngineError &error) override;

private:
    SensetimeNlpEnginePrivate *d;
};

#endif // SENSETIMENLPENGINE_H
